package org.jboss.soa.esb.samples.quickstarts.bpm_orchestration5.esb_actions;

/*
 * JBoss, Home of Professional Open Source
 * Copyright 2006, JBoss Inc., and others contributors as indicated 
 * by the @authors tag. All rights reserved. 
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors. 
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 * 
 * (C) 2005-2006,
 * @author JBoss Inc.
 */

import org.jboss.soa.esb.actions.AbstractActionPipelineProcessor;
import org.jboss.soa.esb.actions.ActionProcessingException;
import org.jboss.soa.esb.actions.ActionLifecycleException;
import org.jboss.soa.esb.helpers.ConfigTree;
import org.jboss.soa.esb.message.Message;
import org.jboss.soa.esb.listeners.ListenerTagNames;
// import org.jboss.soa.esb.http.HttpRequest;
import org.jboss.soa.esb.http.HttpResponse;
import javax.servlet.http.HttpServletResponse;
import org.jboss.soa.esb.Service;

import org.jboss.soa.esb.store.Customer;
import org.jboss.soa.esb.store.OrderHeader;


// RestEasy Way
import org.jboss.resteasy.plugins.providers.atom.Feed; 
import org.jboss.resteasy.plugins.providers.atom.Link;
import org.jboss.resteasy.plugins.providers.atom.Person;
import org.jboss.resteasy.plugins.providers.atom.Entry;
import org.jboss.resteasy.plugins.providers.atom.Content;
import javax.ws.rs.core.MediaType;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.Marshaller;

import java.io.StringWriter;
import java.io.Writer;
import java.net.URI;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

// for experimental purposes
import org.jboss.internal.soa.esb.addressing.helpers.EPRHelper;
import org.jboss.soa.esb.addressing.eprs.LogicalEPR;

public class MyAtomAction extends AbstractActionPipelineProcessor {

	protected ConfigTree _config;
    private Service service;
    private static List<Entry> entries = new ArrayList<Entry>();
	// using a static is a horrible idea, just trying to make this demo simple
	// if I really wanted to share data between services then something like JBossCache
	// would likely make the most sense.
    private Entry entry;
    private Content description;

    public MyAtomAction(ConfigTree config) {
		_config = config;
        service = new Service(_config.getParent().getAttribute(
		ListenerTagNames.SERVICE_CATEGORY_NAME_TAG), 
		_config.getParent().getAttribute(ListenerTagNames.SERVICE_NAME_TAG));
        
    }
    public void initialise() throws ActionLifecycleException {
	    System.out.println("\n %%%%% initialise() %%%%% ");	
		System.out.println("Hit this URL in Firefox/Atom reader - http://localhost:8080/DVD_Pet_StoreDemo_5.0.0/http/storeOrders");
    }
	public void destroy() throws ActionLifecycleException {
		System.out.println("\n %%%%% destroy() %%%%% ");	
    } 
    public Message process(Message message) throws ActionProcessingException {

        System.out.println("&&&&&&&&&&&&& MyAction.process ATOM Request &&&&&&&&&&&&&&&&&&");
		
		try {
			//SyndFeed feed = new SyndFeedImpl();
			Feed feed = new Feed();
			//feed.setFeedType("atom_1.0");

			feed.setTitle("ESB News (MyAtomProject)");
			//feed.setLink("http://localhost:8080/Quickstart_atom_publisher/http/sales");
			//feed.setDescription("This feed has been created using JBossESB+Rome");
			feed.setUpdated(new java.util.Date());	
			
			// feed.setEntries(entries);
			Link link = new Link();
			link.setHref(new URI("http://localhost"));
			link.setRel("edit");
			
			feed.getLinks().add(link);
			
			Person person = new Person("Burr Sutter");
			feed.getAuthors().add(person);
			
		    feed.getEntries().addAll(entries); 
		    
		    JAXBContext context = JAXBContext.newInstance(Feed.class);
		    Marshaller m = context.createMarshaller();
			Writer writer = new StringWriter();
			
			m.marshal(feed,writer);
			writer.close();
			String response = writer.toString();
			//System.out.println(response);
			message.getBody().add(response);
			
			HttpResponse responseInfo = new HttpResponse(HttpServletResponse.SC_OK);
			responseInfo.setContentType("application/atom+xml");
            responseInfo.setResponse(message);
						
		} catch (Exception e) {
			e.printStackTrace(System.out);		 
			throw new ActionProcessingException(e.getMessage());
		}        
        return message;

	}

	public Message addNewOrder(Message message)
			throws ActionProcessingException {
		System.out.println("&&&&&&&&&&&&& MyAtomAction.addNewOrder &&&&&&&&&&&&&&&&&&");
				
		OrderHeader header = (OrderHeader) message.getBody().get("orderHeader");
		Customer customer = (Customer) message.getBody().get("customer");
		
		System.out.println("order to add: " + header);
		System.out.println("customerr to add: " + customer);
		
		entry = new Entry();
		entry.setTitle("Sales News - New Order $" + header.getTotalAmount()+ " from " + customer.getFirstName() + " " + customer.getLastName());
						
		entry.setPublished(new java.util.Date());
		
		description = new Content();
		// description.setType(MediaType.TEXT_PLAIN_TYPE);
		description.setType(MediaType.TEXT_HTML_TYPE);
		
		String id = (String) message.getBody().get("linkToProcessID");
		description.setText("<a href=\"http://localhost:8080/jbpm-console/app/procins.jsf?id="+id+"&view=vars\">Order Details</a>" );
		
		entry.setContent(description);
		entries.add(entry);

		// System.out.println("Order: " + header);
		// System.out.println("Entries: " + entries);
		
		System.out.println("&&&&&&&&&&&&& MyAtomAction.addNewOrder &&&&&&&&&&&&&&&&&&");
		return message;
	}
}

